require 'RMagick'
require 'securerandom'
require 'ibo_ipsum'

module IboIpsum
  class Meme
    include Magick

    attr_reader :sentence, :image, :name

    def initialize(sentence, path = default_path)
      @sentence = sentence
      @image = Image.read(path).first
      @name = "meme_#{SecureRandom::hex(3)}.jpg"
    end

    def default_path
      File.join(File.dirname(__FILE__), "../../img/ibo_1.jpg")
    end

    def prepared_sentence
      word_wrap(sentence) + "\n"
    end

    def generate
      text = Draw.new
      text.annotate(image, 0,0,0,0, prepared_sentence) do
        self.gravity = Magick::SouthGravity
        self.pointsize = 35
        self.font_family = "Helvetica"
        self.font_weight = 900
        self.fill = "#FF1493"
        self.stroke = "#FFF"
        self.stroke_width = 1
      end
      save_and_open!
    end

    def save_and_open!
      puts "saved: #{name}"
      image.write name
      `open #{name}`
    end

    private

    # stolen from rails
    def word_wrap(text, options = {})
      line_width = options.fetch(:line_width, 25)
      text.split("\n").collect do |line|
        line.length > line_width ? line.gsub(/(.{1,#{line_width}})(\s+|$)/, "\\1\n").strip : line
      end * "\n"
    end
  end
end
